@@ -79,6 +79,7 @@ namespace jcs {
 
   public:
     Basic3DConversion(Basic3DOutputter* outputter, SeriesHandler* handler);
+    ~Basic3DConversion() {}
     virtual void Convert();
     typedef std::map <VolId, Volume<T> > vMapType;
 
@@ -104,6 +105,6 @@ namespace jcs {
   };
 }
 
-#include "Basic3DOutputter.txx"
+#include "Basic3DConversion.txx"
 
 #endif
