@@ -12,7 +12,6 @@
 #include "BasicVolumeFormat.h"
 
 using namespace jcs;
-using namespace std;
 
 ///
 /**
@@ -20,9 +19,9 @@ using namespace std;
 BasicVolumeFormat::BasicVolumeFormat(const char* filename, 
 const char* header_extension,
 const char* raw_extension) 
-: mFileName(wxString(filename, wxConvLocal)), 
-mHeaderExtension(wxString(header_extension, wxConvLocal)), 
-mRawExtension(wxString(raw_extension, wxConvLocal))
+: mFileName(filename),
+mHeaderExtension(header_extension),
+mRawExtension(raw_extension)
 {
   wxFileName::Mkdir(mFileName.GetPath(wxPATH_GET_VOLUME), 0777, wxPATH_MKDIR_FULL);
 }
@@ -32,35 +31,45 @@ mRawExtension(wxString(raw_extension, wxConvLocal))
 */
 BasicVolumeFormat::~BasicVolumeFormat()
 {
-  if (mHeaderFile.is_open()) { mCloseHeaderFile(); }
-  if (mRawDataFile.is_open()) { mCloseRawDataFile(); }
+  if (mHeaderFile.is_open()) {
+    mCloseHeaderFile();
+  }
+  if (mRawDataFile.is_open()) {
+    mCloseRawDataFile();
+  }
 }
 
 
 /// Tries to open a header file in given 'mode'.
 /**
   \param mode Open mode for file.
-  \return Status code, 0 on bad file name, false on failure of 'open' call,
+  \return Status code, false on bad file name, false on failure of 'open' call,
   true on success of 'open' call.
 */
 int
 BasicVolumeFormat::mOpenHeaderFile(std::ios::openmode mode) 
 {
-  if (!mFileName.IsOk()) {
-    return false;
+  bool retval = false;
+
+  if (mFileName.IsOk()) {
+    if (mHeaderFile.is_open()) {
+      mHeaderFile.close();
+    }
+    mHeaderFile.clear();
+    mFileName.SetExt(mHeaderExtension);
+    
+    // Test possible overwrite condition.
+    if (mFileName.FileExists()) {
+      std::string errorMsg = "Warning: File exists, will overwrite ";
+      errorMsg += mFileName.GetFullPath();
+      wxLogError(wxFormatString(errorMsg));
+      std::cout << errorMsg << std::endl;
+    }
+
+    mHeaderFile.open((const char *) mFileName.GetFullPath(), mode);
+    retval = mHeaderFile.good();
   }
-  if (mHeaderFile.is_open()) {
-    mHeaderFile.close();
-  }
-
-  mHeaderFile.clear();
-
-  mFileName.SetExt(mHeaderExtension);
-
-  std::string filename(mFileName.GetFullPath().mb_str(wxConvLocal));
-  mHeaderFile.open(filename.c_str(), mode);
-
-  return mHeaderFile.good();
+  return retval;
 }
 
 
@@ -75,15 +84,15 @@ BasicVolumeFormat::AppendRawData(char* data, size_t n_bytes)
 {
   int retval = false;
   wxString extUsed;
-  ios_base::openmode o_mode = ios::out | ios::binary;
-
+  std::ios_base::openmode o_mode = std::ios::out | std::ios::binary;
+  
   if (mRawExtension != _T("")) {
     extUsed = mRawExtension;
-    o_mode |= ios::trunc;
+    o_mode |= std::ios::trunc;
   }
   else {
     extUsed = mHeaderExtension;
-    o_mode |= ios::app;
+    o_mode |= std::ios::app;
   }
   mFileName.SetExt(extUsed);
 
@@ -92,7 +101,15 @@ BasicVolumeFormat::AppendRawData(char* data, size_t n_bytes)
       if (mRawExtension != _T("")) {
         mRawDataFile.clear();
       }
-      mRawDataFile.open(mFileName.GetFullPath().mb_str(wxConvLocal), o_mode);
+      
+      // Test possible overwrite condition.      
+      if (mFileName.FileExists() && (o_mode & std::ios::trunc)) {
+        std::string errorMsg = "Warning: File exists, will overwrite ";
+        errorMsg += mFileName.GetFullPath();
+        wxLogError(wxFormatString(errorMsg));
+        std::cout << errorMsg << std::endl;
+      }
+      mRawDataFile.open((const char *) mFileName.GetFullPath(), o_mode);
     }
 
     if (mRawDataFile.good()) {
