@@ -19,6 +19,9 @@
 
 using namespace jcs;
 
+///
+/**
+*/
 template <class T>
 struct GetFirst : std::unary_function<T, typename T::first_type> {
   typename T::first_type operator()(const T& t) const {
@@ -26,22 +29,34 @@ struct GetFirst : std::unary_function<T, typename T::first_type> {
   }
 };
 
+
+///
+/**
+*/
 static void
 DeleteHandler (std::pair<std::string, SeriesHandler*> mPair)
 {
   delete mPair.second;
 }
 
+
+///
+/**
+*/
 Converter::Converter(int type)
 {
   mpOutputter = OutputFactory::CreateNewOutputter(type);
 }
 
+
+///
+/**
+*/
 Converter::~Converter()
 {
   HandlerMap::iterator it = mHandlerMap.begin();
   HandlerMap::iterator it_end = mHandlerMap.end();
-  for (;it != it_end; it++) {
+  for (;it != it_end; ++it) {
     delete it->second;
   }
   delete mpOutputter;
@@ -103,7 +118,9 @@ Converter::mAddFile(const wxString& path, const wxString& match, wxString& messa
     return false;
   }
 
-  DicomFile input(path.mb_str(wxConvLocal));
+//  std::cout << "Converter::mAddFile, path: " << path << std::endl;
+
+  DicomFile input(path);
   if (!input.IsOk()) {
     message = wxString(input.ErrorMessage(), wxConvLocal);
     return false;
@@ -120,7 +137,8 @@ Converter::mAddFile(const wxString& path, const wxString& match, wxString& messa
   }
 
   std::string series_uid;
-  input.Find("SeriesInstanceUid", series_uid);
+  //input.Find("SeriesInstanceUid", series_uid);
+  input.Find("SeriesInstanceUID", series_uid);
 
   // Fix problems with termination
   std::string temp(series_uid.c_str());
@@ -130,10 +148,12 @@ Converter::mAddFile(const wxString& path, const wxString& match, wxString& messa
   mSeriesToUpdate.insert(series_uid);
   
   if (!mHandlerMap.count(series_uid)) {
-    mHandlerMap[series_uid] = HandlerFactory::CreateHandler(path.mb_str(wxConvLocal));
+    //mHandlerMap[series_uid] = HandlerFactory::CreateHandler(path.mb_str(wxConvLocal));
+    mHandlerMap[series_uid] = HandlerFactory::CreateHandler(path);
   }
 
-  if (!mHandlerMap[series_uid]->AddFile(path.mb_str(wxConvLocal))) {
+  //if (!mHandlerMap[series_uid]->AddFile(path.mb_str(wxConvLocal))) {
+  if (!mHandlerMap[series_uid]->AddFile(path)) {
     message = _T("File already in list.");
     return false;
   }
@@ -150,7 +170,7 @@ Converter::UpdateOutput()
 {
   std::set<std::string>::iterator it = mSeriesToUpdate.begin();
   std::set<std::string>::iterator it_end = mSeriesToUpdate.end();
-  for (; it != it_end; it++) {
+  for (; it != it_end; ++it) {
     mpOutputter->UpdateOutputForSeries(mHandlerMap[*it]);
   }
   mSeriesToUpdate.clear();
@@ -165,7 +185,7 @@ Converter::UpdateAllOutput()
 {
   HandlerMap::iterator it = mHandlerMap.begin();
   HandlerMap::iterator it_end = mHandlerMap.end();
-  for (; it != it_end; it++) {
+  for (; it != it_end; ++it) {
     mpOutputter->UpdateOutputForSeries(it->second);
   }
 }
@@ -213,7 +233,7 @@ Converter::GetSeriesList()
   HandlerMap::iterator it = mHandlerMap.begin();
   HandlerMap::iterator it_end = mHandlerMap.end();
   std::vector<std::string> v;
-  for (; it != it_end; it++) {
+  for (; it != it_end; ++it) {
     v.push_back(it->first);
   }
   return v;
@@ -230,8 +250,10 @@ Converter::ConvertAll()
 
   HandlerMap::iterator it = mHandlerMap.begin();
   HandlerMap::iterator it_end = mHandlerMap.end();
-  for (; it != it_end; it++) {
-    if (mCancel) { break; }
+  for (; it != it_end; ++it) {
+    if (mCancel) {
+      break;
+    }
     mpOutputter->ConvertSeries(it->second);
   }
 }
