@@ -1,23 +1,20 @@
 /// FslNiftiOutputter.cpp
 /**
-*/
-
-#pragma warning(disable: 4996)
+ */
 
 #include <string>
 #include <vector>
 
 #include "SeriesHandler.h"
-#include "NiftiVolume.h"
+#include "NiftiOutputterBase.h"
 #include "FslNiftiOutputter.h"
 
-using namespace std;
 using namespace jcs;
 
 ///
 /**
-*/
-FslNiftiOutputter::FslNiftiOutputter() : 
+ */
+FslNiftiOutputter::FslNiftiOutputter() :
 NiftiOutputterBase(CreateOptions())
 {
 }
@@ -25,7 +22,7 @@ NiftiOutputterBase(CreateOptions())
 
 ///
 /**
-*/
+ */
 Options
 FslNiftiOutputter::CreateOptions()
 {
@@ -37,7 +34,7 @@ FslNiftiOutputter::CreateOptions()
 
 ///
 /**
-*/
+ */
 void
 FslNiftiOutputter::UpdateOutputForSeries(SeriesHandler* handler)
 {
@@ -47,9 +44,9 @@ FslNiftiOutputter::UpdateOutputForSeries(SeriesHandler* handler)
 
 ///
 /** Perform the conversion on the given series.
-    \param handler A pointer to a SeriesHandler.
-    \return Status code.
-*/
+ *    \param handler A pointer to a SeriesHandler.
+ *    \return Status code.
+ */
 int
 FslNiftiOutputter::ConvertSeries(SeriesHandler* handler)
 {
@@ -59,32 +56,32 @@ FslNiftiOutputter::ConvertSeries(SeriesHandler* handler)
 
   switch (bits_allocated + pixel_rep) {
 
-  case 8 : {
+    case 8 : {
       FslNiftiConversion<wxUint8> conversion(this, handler);
       conversion.Convert();
       break;
     }
-  case 9 : {
+    case 9 : {
       FslNiftiConversion<wxInt8> conversion(this, handler);
       conversion.Convert();
       break;
     }
-  case 16 : {
+    case 16 : {
       FslNiftiConversion<wxUint16> conversion(this, handler);
       conversion.Convert();
       break;
     }
-  case 17 : {
+    case 17 : {
       FslNiftiConversion<wxInt16> conversion(this, handler);
       conversion.Convert();
       break;
     }
-  case 32 : {
+    case 32 : {
       FslNiftiConversion<wxUint32> conversion(this, handler);
       conversion.Convert();
       break;
     }
-  case 33 : {
+    case 33 : {
       FslNiftiConversion<wxInt32> conversion(this, handler);
       conversion.Convert();
       break;
