@@ -8,6 +8,7 @@
 #include <string>
 #include <map>
 
+#include "NiftiOutputterBase.h"
 #include "NiftiOutputter.h"
 #include "NiftiVolume.h"
 
@@ -44,7 +45,6 @@ namespace jcs {
     virtual std::vector<double> GetRotationMatrix(const VolId& id);
 
   private:
-    //void WriteGradientFiles();
 
   };
 
@@ -67,10 +67,21 @@ namespace jcs {
 
     NiftiConversion<T>::GetHeaderForSeries();
 
-    if (this->mHeader->hdr.datatype == DT_UINT16) {
-      this->mHeader->hdr.datatype = DT_INT16;
+	if (this->mHeader->hdr.datatype == DT_UINT16) {
+	 	int bits;
+		this->mHandler->Find("BitsStored", bits);
+		if (bits == 16) {
+			// it would be better to name the actual output file but that is
+			// more complicated to do than it should be and I'm not fixing it now
+			std::string patient_name;
+			this->mHandler->Find("PatientName", patient_name);
+			int series_number;
+			this->mHandler->Find("SeriesNumber", series_number);
+			wxLogMessage(_("%s series %d: output will be unsigned 16 bit."),
+				patient_name, series_number);
+		}
+		else this->mHeader->hdr.datatype = DT_INT16;
     }
-    //if (this->mHandler->IsDti()) Basic3DConversion<T>::WriteGradientFiles();
   }
 
 
