@@ -37,12 +37,14 @@ GeEpiHandler::ReadVolIds(DicomFile& file)
 
   int image_number, number_of_slices;
 
-  if (!file.Find("InstanceNumber", image_number))
-  wxLogError(_("Instance number not found"));
+  if (!file.Find("InstanceNumber", image_number)) {
+    wxLogError(_("Instance number not found"));
+  }
 
   Dictionary* Excite = Excite_Dictionary::Instance();
-  if (!file.Find(Excite->Lookup("Locations_in_acquisition"), number_of_slices))
-  wxLogError(_("Locations_in_acquisition not found"));
+  if (!file.Find(Excite->Lookup("Locations_in_acquisition"), number_of_slices)) {
+    wxLogError(_("Locations_in_acquisition not found"));
+  }
 
   int vol_no = static_cast<int>(floor(static_cast<double>((image_number - 1))
   /number_of_slices) + 1);
