@@ -3,9 +3,13 @@
 */
 
 #if defined(__WXGTK__) || defined(__WXMOTIF__)
-#include <wx/wx.h>
+  #include <wx/wx.h>
 #endif
 
+#include <vector>
+#include <algorithm>
+#include <limits>
+
 #include <wx/wxprec.h>
 #include <wx/image.h>
 #include <wx/filename.h>
@@ -19,16 +23,11 @@
 #include <wx/log.h>
 #include <wx/progdlg.h>
 
-#include <vector>
-#include <algorithm>
-#include <limits>
-
 #include "DicomFile.h"
 #include "ImageView.h"
 #include "StringConvert.h"
 
 using namespace jcs;
-using namespace std;
 
 wxImage CreateImage(DicomFile& file);
 
@@ -46,7 +45,6 @@ bool useDefaultWC = true;
 int width = 0;
 int center = 0;
 
-
 BEGIN_EVENT_TABLE(BitmapWindow, wxWindow)
 
 EVT_PAINT			(BitmapWindow::OnPaint)
@@ -57,6 +55,9 @@ EVT_LEFT_DCLICK     (BitmapWindow::OnDoubleClick)
 
 END_EVENT_TABLE()
 
+///
+/**
+ */
 BitmapWindow::BitmapWindow(ImageViewerBase* parent, const wxBitmap& bitmap)
 : wxWindow(parent, -1, wxDefaultPosition, wxDefaultSize), mBitmap(bitmap), mPoint(wxDefaultPosition) 
 {
@@ -64,14 +65,21 @@ BitmapWindow::BitmapWindow(ImageViewerBase* parent, const wxBitmap& bitmap)
   myParent = parent;
 }
 
+
+///
+/**
+ */
 void
 BitmapWindow::SetBitmap(const wxBitmap& bitmap)
 {
   mBitmap = bitmap;
   Refresh();
-
 }
 
+
+///
+/**
+ */
 void
 BitmapWindow::OnPaint(wxPaintEvent& event)
 {
@@ -80,13 +88,18 @@ BitmapWindow::OnPaint(wxPaintEvent& event)
 }
 
 
-
+///
+/**
+ */
 void
 BitmapWindow::OnErase(wxEraseEvent& event)
 {
 }
 
 
+///
+/**
+ */
 void
 BitmapWindow::OnMouseDown(wxMouseEvent& event)
 {
@@ -94,6 +107,10 @@ BitmapWindow::OnMouseDown(wxMouseEvent& event)
   useDefaultWC = false;
 }
 
+
+///
+/**
+ */
 void
 BitmapWindow::OnMouseMotion(wxMouseEvent& event)
 {
@@ -108,6 +125,10 @@ BitmapWindow::OnMouseMotion(wxMouseEvent& event)
   }
 }
 
+
+///
+/**
+ */
 void
 BitmapWindow::OnDoubleClick(wxMouseEvent& event)
 {
@@ -115,6 +136,7 @@ BitmapWindow::OnDoubleClick(wxMouseEvent& event)
   myParent->UpdateImage();
 }
 
+
 BEGIN_EVENT_TABLE(ImageViewerBase, wxFrame)  //Dialog)
 
 EVT_SCROLL		    (             ImageViewerBase::OnSlide)
@@ -130,6 +152,9 @@ EVT_CONTEXT_MENU	(             ImageViewerBase::OnContextMenu)
 END_EVENT_TABLE()
 
 
+///
+/**
+ */
 ImageViewerBase::ImageViewerBase(wxWindow* parent, const wxString& title)
 : wxFrame(parent, -1, title, wxDefaultPosition, wxDefaultSize), mTimer(this, TIMER_ID)
 //: wxDialog(parent, -1, title, wxDefaultPosition, wxDefaultSize), mTimer(this, TIMER_ID)
@@ -168,7 +193,10 @@ ImageViewerBase::ImageViewerBase(wxWindow* parent, const wxString& title)
 }
 
 
-ImageViewer::ImageViewer(wxWindow* parent, const vector<wxString>& names, const wxString& show_first) 
+///
+/**
+ */
+ImageViewer::ImageViewer(wxWindow* parent, const std::vector<wxString>& names, const wxString& show_first) 
 : ImageViewerBase(parent, show_first), showFirst(show_first), filenames(names)
 {
   wxInitAllImageHandlers();
@@ -188,12 +216,19 @@ ImageViewer::ImageViewer(wxWindow* parent, const vector<wxString>& names, const
 }
 
 
+///
+/**
+ */
 void 
 ImageViewerBase::OnSlide(wxScrollEvent& event)
 {
   UpdateImage();
 }
 
+
+///
+/**
+ */
 void
 ImageViewerBase::OnPlay(wxCommandEvent& event)
 {
@@ -208,6 +243,10 @@ ImageViewerBase::OnPlay(wxCommandEvent& event)
   }
 }
 
+
+///
+/**
+ */
 void
 ImageViewerBase::OnTimer(wxTimerEvent& event)
 {
@@ -221,6 +260,10 @@ ImageViewerBase::OnTimer(wxTimerEvent& event)
   UpdateImage();
 }
 
+
+///
+/**
+ */
 void
 ImageViewer::OnWindow(wxCommandEvent& event) 
 {
@@ -233,6 +276,10 @@ ImageViewer::OnWindow(wxCommandEvent& event)
   UpdateImage();
 }
 
+
+///
+/**
+ */
 void
 ImageViewerBase::OnReset(wxCommandEvent& event)
 {
@@ -240,6 +287,10 @@ ImageViewerBase::OnReset(wxCommandEvent& event)
   UpdateImage();
 }
 
+
+///
+/**
+ */
 void
 ImageViewerBase::SetImage(wxImage image)
 {
@@ -256,9 +307,12 @@ ImageViewerBase::SetImage(wxImage image)
     SetSize(newSize);
   }
   mImage = image;
-  
 }
 
+
+///
+/**
+ */
 void
 ImageViewer::UpdateImage()
 {
@@ -273,6 +327,9 @@ ImageViewer::UpdateImage()
 }
 
 
+///
+/**
+ */
 void
 ImageViewerBase::OnContextMenu(wxContextMenuEvent& event)
 {
@@ -285,6 +342,10 @@ ImageViewerBase::OnContextMenu(wxContextMenuEvent& event)
   PopupMenu(&menu, ScreenToClient(event.GetPosition()));
 }
 
+
+///
+/**
+ */
 void
 ImageViewerBase::OnSave(wxCommandEvent& event)
 {
@@ -302,11 +363,13 @@ ImageViewerBase::OnSave(wxCommandEvent& event)
       _T("File was not saved"), wxOK | wxCENTRE, this);
     }
   }
-
   dlg->Destroy();
-
 }
 
+
+///
+/**
+ */
 void
 ImageViewerBase::OnSaveAll(wxCommandEvent& event)
 {
@@ -343,21 +406,31 @@ ImageViewerBase::OnSaveAll(wxCommandEvent& event)
   dlg->Destroy();
 }
 
+
+///
+/**
+ */
 void
 ImageViewerBase::OnClose(wxCommandEvent& event)
 {
   Close();
 }
 
+
+///
+/**
+ */
 template <class T> wxImage
 GetImage(DicomFile& file)
 {
   int columns;
   int rows;
-  file.Find("ImageColumns", columns);
-  file.Find("ImageRows", rows);
+  //file.Find(DT_IMAGECOLUMNS, columns);
+  file.Find("Columns", columns);
+  //file.Find(DT_IMAGEROWS, rows);
+  file.Find("Rows", rows);
 
-  vector<T> data;
+  std::vector<T> data;
   if (file.PixelData(data, columns*rows*sizeof(T)) == 0) {
     wxLogError(_T("Unable to retrieve pixel data."));
   }
@@ -414,16 +487,21 @@ GetImage(DicomFile& file)
   }
 
   return wxImage(columns, rows, my_data, false);
-
 }
 
+
+///
+/**
+ */
 wxImage
 GetRgbImage(DicomFile& file)
 {
   int columns;
   int rows;
-  file.Find("ImageColumns", columns);
-  file.Find("ImageRows", rows);
+  //file.Find(DT_IMAGECOLUMNS, columns);
+  file.Find("Columns", columns);
+  //file.Find(DT_IMAGEROWS, rows);
+  file.Find("Rows", rows);
 
   unsigned char* data = (unsigned char*) malloc(columns*rows*3);
   file.PixelData(data, columns*rows*sizeof(unsigned char)*3);
@@ -432,11 +510,14 @@ GetRgbImage(DicomFile& file)
 }
 
 
+///
+/**
+ */
 wxImage
 CreateImage(DicomFile& file)
 {
   wxImage image;
-  string pi;
+  std::string pi;
   
   if (!file.Find("PhotometricInterpretation", pi)) {
     wxLogError(_T("File does not contain image data."));
@@ -484,13 +565,17 @@ CreateImage(DicomFile& file)
 }
 
 
+///
+/**
+ */
 MultiFrameImageViewer::MultiFrameImageViewer(wxWindow* parent, const wxString& name) 
 : ImageViewerBase(parent, name)
 {
-
   DicomFile file(name.mb_str(wxConvLocal));
-  file.Find("ImageColumns", columns);
-  file.Find("ImageRows", rows);
+  //file.Find(DT_IMAGECOLUMNS, columns);
+  file.Find("Columns", columns);
+  //file.Find(DT_IMAGEROWS, rows);
+  file.Find("Rows", rows);
   file.Find("NumberOfFrames", frames);
 
   goodVolume = CreateVolume(file);
@@ -502,35 +587,45 @@ MultiFrameImageViewer::MultiFrameImageViewer(wxWindow* parent, const wxString& n
 }
 
 
+///
+/**
+ */
 void 
 MultiFrameImageViewer::UpdateImage()
 {
   int frame = mpSliceSlider->GetValue();
-  if (goodVolume)	{ SetImage(GetImage(frame)); }
+  if (goodVolume) {
+    SetImage(GetImage(frame));
+  }
   wxLogStatus(_T("%d"), frame);
 }
 
 
+///
+/**
+ */
 template <class T> void
-GetVolume(DicomFile& file, vector<vector<wxUint8> > &volume)
+GetVolume(DicomFile& file, std::vector<std::vector<wxUint8> > &volume)
 {
   wxBusyCursor busy;
   long columns, rows, frames;
-  file.Find("ImageColumns", columns);
-  file.Find("ImageRows", rows);
+  //file.Find(DT_IMAGECOLUMNS, columns);
+  file.Find("Columns", columns);
+  //file.Find(DT_IMAGEROWS, rows);
+  file.Find("Rows", rows);
   file.Find("NumberOfFrames", frames);
 
   volume.resize(frames);
-  for (long i = 0; i < frames; ++i)
-  volume[i].resize(rows*columns*3);
-
-  vector<T> data;
-  file.PixelData(data, columns*rows*frames*sizeof(T));
+  for (long i = 0; i < frames; ++i) {
+    volume[i].resize(rows*columns*3);
+  }
 
+  std::vector<T> data;
+  file.PixelData(data, columns * rows * frames * sizeof(T));
 
   // rescale to unsigned 8 bit
-  typename vector<T>::iterator frame_start = data.begin();
-  typename vector<T>::iterator frame_end;
+  typename std::vector<T>::iterator frame_start = data.begin();
+  typename std::vector<T>::iterator frame_end;
   wxUint8 char_max = std::numeric_limits<wxUint8>::max();
   
   while (frame_start < data.end()) {
@@ -541,7 +636,7 @@ GetVolume(DicomFile& file, vector<vector<wxUint8> > &volume)
     if ((data_max - data_min) != 0) {
       float scaling = static_cast<float>(char_max)/static_cast<float>(data_max - data_min);
       T* c_ptr = &*frame_start;
-      for (long i = 0; i < columns*rows; ++i) {
+      for (long i = 0; i < columns*rows; ++i) {  //, ++c_ptr) {
         *c_ptr = static_cast<T>((*c_ptr) * scaling - data_min * scaling);
         ++c_ptr;
       }
@@ -563,6 +658,9 @@ GetVolume(DicomFile& file, vector<vector<wxUint8> > &volume)
 }
 
 
+///
+/**
+ */
 wxImage
 MultiFrameImageViewer::GetImage(int frame)
 {
@@ -571,18 +669,23 @@ MultiFrameImageViewer::GetImage(int frame)
 }
 
 
+///
+/**
+ */
 // nb - need to find a multiframe rbg image to test this!
 void
-GetRgbVolume(DicomFile& file, vector<vector<wxUint8> > &volume)
+GetRgbVolume(DicomFile& file, std::vector<std::vector<wxUint8> > &volume)
 {
   wxBusyCursor busy;
   long columns, rows, frames;
-  file.Find("ImageColumns", columns);
-  file.Find("ImageRows", rows);
+  //file.Find(DT_IMAGECOLUMNS, columns);
+  file.Find("Columns", columns);
+  //file.Find(DT_IMAGEROWS, rows);
+  file.Find("Rows", rows);
   file.Find("NumberOfFrames", frames);
 
-  vector<unsigned char> data;
-  file.PixelData(data, columns*rows*frames*sizeof(unsigned char));
+  std::vector<unsigned char> data;
+  file.PixelData(data, columns * rows * frames * sizeof(unsigned char));
   unsigned char* old_ptr = &data.front();
 
   volume.resize(frames);
@@ -598,10 +701,13 @@ GetRgbVolume(DicomFile& file, vector<vector<wxUint8> > &volume)
 }
 
 
+///
+/**
+ */
 bool
 MultiFrameImageViewer::CreateVolume(DicomFile& file)
 {
-  string pi;
+  std::string pi;
 
   if (!file.Find("PhotometricInterpretation", pi)) {
     wxLogError(_T("File does not contain image data."));
