@@ -12,7 +12,7 @@ jcs::operator>> (std::istream &in, MainHeader &mh)
   DicomElementInstance de;
   de.transferSyntaxCode = mh.transferSyntaxCode;
   std::streampos save_position;
-  while (1) {
+  while (true) {
     save_position = in.tellg();
     in >> de;
     if (mh.isPixelData(de)) {
@@ -21,7 +21,6 @@ jcs::operator>> (std::istream &in, MainHeader &mh)
     }
     else {
       mh.mhElements.push_back(de);
-      de.value.assign("");
     }
   }
   return in;
