@@ -2,10 +2,8 @@
 /** Main user interface within McFrame.
 */
 
-#pragma warning( disable : 4786 )
-
 #if defined(__WXGTK__) || defined(__WXMOTIF__)
-#include <wx/wx.h>
+  #include <wx/wx.h>
 #endif
 
 #include <wx/wxprec.h>
@@ -51,6 +49,8 @@
 
 using namespace jcs;
 
+wxDEFINE_EVENT(DROP_EVENT, wxCommandEvent);
+
 BEGIN_EVENT_TABLE(McPanel, wxPanel)
 
 EVT_BUTTON(COMMAND_NEW,               McPanel::OnNew)
@@ -67,7 +67,8 @@ EVT_CHOICE(CHOICE_OUTPUT,             McPanel::OnChoiceOutput)
 
 EVT_TREE_SEL_CHANGED(SOURCE_CTRL,     McPanel::OnSourceSelect)
 EVT_TREE_SEL_CHANGED(OUTPUT_CTRL,     McPanel::OnOutputSelect)
-EVT_TREE_END_LABEL_EDIT(OUTPUT_CTRL,  McPanel::OnEditEnd)
+
+//EVT_TREE_END_LABEL_EDIT(OUTPUT_CTRL,  McPanel::OnEditEnd)
 
 EVT_CONTEXT_MENU(                     McPanel::OnContextMenu)
 
@@ -78,10 +79,16 @@ EVT_MENU(COMMAND_IMAGE,               McPanel::OnImage)
 EVT_MENU(COMMAND_DIRECTORY,           McPanel::OnDirectory)
 EVT_MENU(COMMAND_RENAME,              McPanel::OnRename)
 
-EVT_DROP_FILES(                       McPanel::OnDropFiles)
+//EVT_DROP_FILES(                       McPanel::OnDropFiles)
+//EVT_COMMAND(wxID_ANY, DROP_EVENT, McPanel::OnDropFiles)
 
 END_EVENT_TABLE()
 
+
+class DnDFile;
+///
+/**
+*/
 McPanel::McPanel(wxWindow* parent) : wxPanel(parent, -1)
 {
   m_output_type = 0;
@@ -145,6 +152,9 @@ McPanel::McPanel(wxWindow* parent) : wxPanel(parent, -1)
 
   while (!wxDir::Exists(rootdir)) {
     rootdir = wxDirSelector(_("Choose a directory for output"));
+    if (rootdir.empty()) {
+      GetParent()->Close(false);
+    }
   }
   
   mpOutputCtrl = new NewOutputTreeCtrl(this, OUTPUT_CTRL, rootdir);
@@ -171,10 +181,10 @@ McPanel::McPanel(wxWindow* parent) : wxPanel(parent, -1)
   // add output control sizer to panel sizer
   panelSizer->Add(oSizer, 1, wxEXPAND|wxLEFT|wxRIGHT, 20);
 
-  mpPathInfo = new wxStaticText(this, -1, ::wxGetCwd());
-  panelSizer->Add(mpPathInfo, 0, wxALL, 20);
+ // mpPathInfo = new wxStaticText(this, -1, ::wxGetCwd());
+//  panelSizer->Add(mpPathInfo, 0, wxALL, 20);
 
-  panelSizer->Add(new wxStaticLine(this, -1), 0, wxEXPAND);
+//  panelSizer->Add(new wxStaticLine(this, -1), 0, wxEXPAND);
 
   // create button sizer
   wxBoxSizer* buttonSizer = new wxBoxSizer(wxHORIZONTAL);
@@ -201,9 +211,12 @@ McPanel::McPanel(wxWindow* parent) : wxPanel(parent, -1)
   mpOutputCtrl->SetOutputter(mpConverter->GetOutputter());
 
   #if defined(__WXMSW__) 
-  DragAcceptFiles(true);
+//  DragAcceptFiles(true); // oh look at one point I knew this.
   #endif
 
+  this->SetDropTarget(new DnDFile(this));
+  //Bind(DROP_EVENT, &McPanel::OnDropFiles, this, wxID_ANY);
+
   if (wxGetApp().argc > 1) {
     for (int i = 1; i < wxGetApp().argc; ++i) {
       wxFileName filename(wxGetApp().argv[i]);
@@ -221,11 +234,15 @@ McPanel::McPanel(wxWindow* parent) : wxPanel(parent, -1)
     ResetOutput();
     RefreshSourceCtrl();
     ShowMessageBox();
+
     ::wxGetTopLevelParent(this)->Raise();
   }
 }
 
 
+///
+/**
+*/
 McPanel::~McPanel()
 {
   wxString rootdir = mpOutputCtrl->GetItemText(mpOutputCtrl->GetRootItem());
@@ -235,19 +252,25 @@ McPanel::~McPanel()
 
 
 // kindof annoying this way, but okay for now
+///
+/**
+*/
 void
 McPanel::RefreshSourceCtrl()
 {
   std::vector<std::string> sv = mpConverter->GetSeriesList();
   std::vector<std::string>::iterator it = sv.begin();
   std::vector<std::string>::iterator it_end = sv.end();
-  for (; it != it_end; it++) {
+  for (; it != it_end; ++it) {
     SeriesHandler* series = mpConverter->GetHandler(*it);
     mpSourceCtrl->AddSeries(series);
   } 
 }
 
 
+///
+/**
+*/
 void
 McPanel::ResetOutput()
 {
@@ -257,6 +280,9 @@ McPanel::ResetOutput()
 }
 
 
+///
+/**
+*/
 void
 McPanel::SetSplitDirs(bool split)
 {
@@ -264,6 +290,9 @@ McPanel::SetSplitDirs(bool split)
 }
 
 
+///
+/**
+*/
 void
 McPanel::SetSplitSubj(bool split)
 {
@@ -271,6 +300,9 @@ McPanel::SetSplitSubj(bool split)
 }
 
 
+///
+/**
+
 void
 McPanel::SetPathInfo(wxString path)
 {
@@ -287,10 +319,13 @@ McPanel::SetPathInfo(wxString path)
       path.Prepend(mpOutputCtrl->GetItemText(item));
     }
   }
-  mpPathInfo->SetLabel(path);
+//  mpPathInfo->SetLabel(path);
 }
+*/
 
-
+///
+/**
+*/
 void
 McPanel::ShowMessageBox()
 {
@@ -331,8 +366,11 @@ McPanel::mAddSomeFilesDialog(wxArrayString files, const wxChar* msg)
   wxPD_CAN_ABORT | wxPD_APP_MODAL | wxPD_SMOOTH);
   
   files.Sort();
-  for (unsigned int i = 0; i < nfiles; ++i) {
-    mpConverter->AddFile(files.Item(i).c_str());
+  wxArrayString::iterator it = files.begin();
+  wxArrayString::iterator it_end = files.end();
+  for (unsigned int i = 0; it != it_end; ++it, ++i) {
+    wxFileName filename(*it);
+    mpConverter->AddFile(filename.GetFullPath());
     if (i % tuneUpdate == 0) {
       if (!p_dlg->Update(i)) {
         break;
@@ -340,10 +378,14 @@ McPanel::mAddSomeFilesDialog(wxArrayString files, const wxChar* msg)
     }
   }
   p_dlg->Destroy();
+  wxLogStatus(_("Finished."));
 }
 
 
 // EVENT HANDLERS
+///
+/**
+*/
 void
 McPanel::OnQuit(wxCommandEvent& event)
 {
@@ -351,6 +393,9 @@ McPanel::OnQuit(wxCommandEvent& event)
 }
 
 
+///
+/**
+*/
 void
 McPanel::OnContextMenu(wxContextMenuEvent& event)
 {
@@ -379,6 +424,9 @@ McPanel::OnContextMenu(wxContextMenuEvent& event)
 }
 
 
+///
+/**
+*/
 void
 McPanel::OnChoiceOutput(wxCommandEvent& event)
 {
@@ -394,6 +442,9 @@ McPanel::OnChoiceOutput(wxCommandEvent& event)
 }
 
 
+///
+/**
+*/
 void
 McPanel::OnSourceSelect(wxTreeEvent& event)
 {
@@ -401,32 +452,41 @@ McPanel::OnSourceSelect(wxTreeEvent& event)
 }
 
 
+///
+/**
+*/
 void
 McPanel::OnOutputSelect(wxTreeEvent& event)
 { 
   // Only do anything if this is a "select" event
   wxTreeItemId item = mpOutputCtrl->GetSelection();
   if (item.IsOk()) {
-    SetPathInfo(mpOutputCtrl->GetStringSelection());
+//    SetPathInfo(mpOutputCtrl->GetStringSelection());
     mpSourceCtrl->UnselectAll();
   }
 }
 
 
+///
+/**
+*/
 void
 McPanel::OnEditBegin(wxTreeEvent& event)
 {
 }
 
 
+///
+/**
+
 void
 McPanel::OnEditEnd(wxTreeEvent& event)
 {
   if (!event.IsEditCancelled()) {
-    SetPathInfo(event.GetLabel());
+//    SetPathInfo(event.GetLabel());
   }
 }
-
+*/
 
 ///
 /** Handler for adding user-chosen set of files.
@@ -442,33 +502,35 @@ McPanel::OnAddFiles(wxCommandEvent& event)
   lastDir,
   _T(""), _("*"),
   wxFD_OPEN|wxFD_MULTIPLE|wxRESIZE_BORDER);
-//  _("DICOM files (*.dcm)|*.dcm|All files|*"),
 
   if (dlg.ShowModal() == wxID_OK) {
     wxBusyCursor busy;
     wxLogStatus(_("Searching directories..."));
     wxArrayString files;
     dlg.GetPaths(files);
+    mAddSomeFilesDialog(files);
+
+    // These three lines permit saving the user's last directory
+    // in their config file.
     wxFileName fn(files[0]);
     lastDir = fn.GetPath();
-    mAddSomeFilesDialog(files);
+    wxConfig::Get()->Write(CFG_lastdir, lastDir);
+    
     mpConverter->UpdateOutput();
     wxLogStatus(_("Creating tree..."));
     RefreshSourceCtrl();
     ResetOutput();
   }
 
-  wxConfig::Get()->Write(CFG_lastdir, lastDir);
   wxLogStatus(_("Finished."));
   ShowMessageBox();
   ::wxGetTopLevelParent(this)->Raise();
 }
 
 
-// Fix: handle dropping dirs too
-///
 /** Handler for drag-and-drop.
 */
+/* Old way, windows only
 void
 McPanel::OnDropFiles(wxDropFilesEvent& event)
 {
@@ -478,7 +540,7 @@ McPanel::OnDropFiles(wxDropFilesEvent& event)
   for (int i = 0; i < nfiles; ++i) {
     wxFileName filename(dropfiles[i]);
     if (filename.FileExists()) {
-      mpConverter->AddFile(filename.GetFullPath().c_str());
+      mpConverter->AddFile(filename.GetFullPath());
     }
     else if (filename.DirExists()) {
       wxArrayString files;
@@ -493,6 +555,46 @@ McPanel::OnDropFiles(wxDropFilesEvent& event)
   ShowMessageBox();
   ::wxGetTopLevelParent(this)->Raise();
 }
+*/
+
+void
+McPanel::OnDropFiles(const wxArrayString& dropfiles)
+{
+
+   int nfiles = dropfiles.GetCount();
+  
+  for (int i = 0; i < nfiles; ++i) {
+    wxFileName filename(dropfiles[i]);
+    if (filename.FileExists()) {
+      mpConverter->AddFile(filename.GetFullPath());
+    }
+    else if (filename.DirExists()) {
+      wxArrayString files;
+      wxDir::GetAllFiles(filename.GetFullPath(), &files);
+      mAddSomeFilesDialog(files);
+    }
+  }
+
+  mpConverter->UpdateOutput();
+  ResetOutput();
+  RefreshSourceCtrl();
+  ShowMessageBox();
+  ::wxGetTopLevelParent(this)->Raise();
+}
+
+
+bool 
+DnDFile::OnDropFiles(wxCoord, wxCoord, const wxArrayString& filenames)
+{
+// 	m_pOwner->droppedFiles = filenames;
+ m_pOwner->OnDropFiles(filenames);
+ /*
+	wxCommandEvent event(DROP_EVENT, wxID_ANY);
+	event.SetEventObject(m_pOwner);
+	m_pOwner->ProcessWindowEvent(event);
+	*/
+  return true;
+}
 
 
 ///
@@ -515,13 +617,19 @@ McPanel::OnAddDir(wxCommandEvent& event)
     wxArrayString files;
     wxDir::GetAllFiles(dlg.GetPath(), &files);
     mAddSomeFilesDialog(files);
+
     lastDir = dlg.GetPath();
     wxConfig::Get()->Write(CFG_lastdir, dlg.GetPath());
+    
+    //mpConverter->UpdateOutput();
+    //RefreshSourceCtrl();
+    //ResetOutput();
   }
-
+  // The next three lines should happen only on wxID_OK...
   mpConverter->UpdateOutput();
   ResetOutput();
   RefreshSourceCtrl();
+  
   wxLogStatus(_("Finished."));
   ShowMessageBox();
   ::wxGetTopLevelParent(this)->Raise();
@@ -634,10 +742,10 @@ McPanel::OnRemove(wxCommandEvent& event)
       std::vector<std::string> series_vector = mpSourceCtrl->GetChildSeries(selected);
 
       std::vector<std::string>::iterator it = series_vector.begin();
-      while (it < series_vector.end()) {
+      std::vector<std::string>::iterator it_end = series_vector.end();
+      for (; it < it_end; ++it) {
         mpConverter->RemoveSeries(*it);
         mpOutputCtrl->RemoveSeries(*it);
-        ++it;
       }
 
       mpSourceCtrl->RemoveBranch(selected);
@@ -648,6 +756,9 @@ McPanel::OnRemove(wxCommandEvent& event)
 }
 
 
+///
+/**
+*/
 void
 McPanel::OnOptions(wxCommandEvent& event)
 {
@@ -658,6 +769,9 @@ McPanel::OnOptions(wxCommandEvent& event)
 }
 
 
+///
+/**
+*/
 void
 McPanel::OnDirectory(wxCommandEvent& event)
 {
@@ -665,6 +779,9 @@ McPanel::OnDirectory(wxCommandEvent& event)
 }
 
 
+///
+/**
+*/
 void
 McPanel::OnNew(wxCommandEvent& event)
 {
@@ -678,6 +795,9 @@ McPanel::OnNew(wxCommandEvent& event)
 }
 
 
+///
+/**
+*/
 void
 McPanel::OnConvert(wxCommandEvent& event)
 {
@@ -686,21 +806,29 @@ McPanel::OnConvert(wxCommandEvent& event)
   wxBusyInfo wait(_("Converting files, please wait..."));
   mpConverter->ConvertAll();
   wxLogStatus(_("Finished."));
+  ShowMessageBox();
   ::wxGetTopLevelParent(this)->Raise();
 }
 
 
+///
+/**
+*/
 void
 McPanel::OnRename(wxCommandEvent& event)
 {
   mpOutputCtrl->OnMenuRename(event);
-  wxString pathInfo = mpOutputCtrl->GetStringSelection();
+/*  wxString pathInfo = mpOutputCtrl->GetStringSelection();
   if (pathInfo != _T("error")) {
     SetPathInfo(pathInfo);
   }
+  */
 }
 
 
+///
+/**
+*/
 void
 McPanel::OnMenuOverride()
 {
@@ -709,6 +837,9 @@ McPanel::OnMenuOverride()
 }
 
 
+///
+/**
+*/
 void
 McPanel::OnOverride(const std::string& seriesUid)
 {
@@ -719,6 +850,9 @@ McPanel::OnOverride(const std::string& seriesUid)
 }
 
 
+///
+/**
+*/
 bool
 McPanel::ShowOptionsDlg(int type, OutputterBase* outputter)
 {
@@ -790,6 +924,9 @@ McPanel::ShowOptionsDlg(int type, OutputterBase* outputter)
 }
 
 
+///
+/**
+*/
 bool 
 McPanel::ShowOverride(int type, OutputterBase* outputter, const std::string& series_uid)
 {
