@@ -6,8 +6,8 @@
 #define MCVERTER_H_
 
 #define NO_CONFIG
-#define _CRT_SECURE_NO_DEPRECATE 1
-#define _CRT_SECURE_NO_WARNINGS 1
+// #define _CRT_SECURE_NO_DEPRECATE 1
+// #define _CRT_SECURE_NO_WARNINGS 1
 #define EXIT_NO_WX -1
 #define EXIT_SUCCESS 0
 #define EXIT_NO_PROCESSING 1
@@ -24,7 +24,7 @@
 #include <wx/dir.h>
 #include <wx/config.h>
 #include <wx/stdpaths.h>
-#include <boost/program_options.hpp>
+#include <wx/tokenzr.h>
 
 #include "OutputFactory.h"
 #include "Converter.h"
