@@ -17,10 +17,12 @@
 #include "Converter.h"
 #include "NewBvOutputter.h"
 
-using namespace std;
 using namespace jcs;
 
 
+///
+/**
+ */
 NewBvOutputter::NewBvOutputter():
 OutputterBase(CreateOptions())
 {
@@ -28,12 +30,20 @@ OutputterBase(CreateOptions())
   mSkip = mOptions.intOptions["skip"];
 }
 
+
+///
+/**
+ */
 NewBvOutputter::~NewBvOutputter()
 {
   mOptions.boolOptions["savev16"] = mSaveV16;
   mOptions.intOptions["skip"] = mSkip;
 }
 
+
+///
+/**
+ */
 Options
 NewBvOutputter::CreateOptions()
 {
@@ -44,34 +54,43 @@ NewBvOutputter::CreateOptions()
   return options;
 }
 
+
+///
+/**
+ */
 void
 NewBvOutputter::RemoveSeries(const std::string& seriesUid)
 {
-  set<OutputList::ListType::key_type> keys;
+  std::set<OutputList::ListType::key_type> keys;
+
   OutputList::ListType::iterator it = mOutputList.fileNameList.begin();
-  while (it != mOutputList.fileNameList.end()) {
+  OutputList::ListType::iterator it_end = mOutputList.fileNameList.end();
+  for (;it != it_end; ++it) {
     if (it->second.seriesUid == seriesUid) {
       keys.insert(it->first);
     }
-    ++it;
   }
 
-  set<OutputList::ListType::key_type>::iterator key_it = keys.begin();
-  while (key_it != keys.end()) {
+  std::set<OutputList::ListType::key_type>::iterator key_it = keys.begin();
+  std::set<OutputList::ListType::key_type>::iterator key_it_end = keys.end();
+  for (;key_it != key_it_end; ++key_it) {
     mOutputList.fileNameList.erase(*key_it);
-    ++key_it;
   }
 }
 
+
+///
+/**
+    \param handler A pointer to a SeriesHandler.
+    \return 1
+*/
 int
 NewBvOutputter::ConvertSeries(SeriesHandler* handler)
 {
-
   int bits_allocated, pixel_rep = 0;
   handler->Find("BitsAllocated", bits_allocated);
   handler->Find("PixelRepresentation", pixel_rep);
 
-
   // Note that mosaic == functional is assumed
   if (handler->IsMosaic()) {
     int nVolumes = handler->GetNumberOfVolumes();
@@ -113,18 +132,21 @@ NewBvOutputter::ConvertSeries(SeriesHandler* handler)
     }
   }
 
-
   return 1;
 }
 
+
+
+///
+/**
+ */
 void
 NewBvOutputter::mConvertFmr(SeriesHandler* handler)
 {
   wxFileName file = GetFileName(handler->GetSeriesUid());
   wxFileName::Mkdir(file.GetPath(wxPATH_GET_VOLUME), 0777, wxPATH_MKDIR_FULL);
   file.SetExt(_T(""));
-  string fname(static_cast<const char*>(file.GetFullPath().mb_str(wxConvLocal)));
-
+  std::string fname(static_cast<const char*>(file.GetFullPath()));  //.mb_str(wxConvLocal)));
 
   FmrHeader header;
   header.volumes = handler->GetNumberOfVolumes() - mSkip;
@@ -137,18 +159,22 @@ NewBvOutputter::mConvertFmr(SeriesHandler* handler)
 
   header.columns = handler->GetColumns();
   header.rows = handler->GetRows();
-  vector<double> res = handler->GetVoxelSize();
+  std::vector<double> res = handler->GetVoxelSize();
   header.IpResX = static_cast<float>(res[0]);
   header.IpResY = static_cast<float>(res[1]);
 
   int layout = static_cast<int>(sqrtf(header.slices));
-  if ((layout * layout) < header.slices) { ++layout; }
+  if ((layout * layout) < header.slices) {
+    ++layout;
+  }
   header.layoutColumns = layout;
   header.layoutRows = layout;
 
   handler->Find("SliceThickness", header.sliceThickness);
   header.sliceGap = res[2] - header.sliceThickness;
-  if (header.sliceGap < 0) { header.sliceGap = 0.0; }
+  if (header.sliceGap < 0) {
+    header.sliceGap = 0.0;
+  }
 
   BvFmr fmr_file(fname);
   fmr_file.WriteFmr(header);
@@ -156,10 +182,13 @@ NewBvOutputter::mConvertFmr(SeriesHandler* handler)
 }
 
 
+///
+/**
+ */
 void
 NewBvOutputter::UpdateOutputForSeries(SeriesHandler* handler)
 {
-  string series_uid(handler->GetSeriesUid());
+  std::string series_uid(handler->GetSeriesUid());
   RemoveSeries(series_uid);
   
   ImageFileName name;
@@ -169,7 +198,7 @@ NewBvOutputter::UpdateOutputForSeries(SeriesHandler* handler)
   // fill in default dirs
   FillInDefaultDirs(name, handler);
 
-  string output_file_uid = series_uid;
+  std::string output_file_uid = series_uid;
 
   //Currently we assume that mosaics == BOLD images....
   if (handler->IsMosaic()) {
@@ -180,7 +209,7 @@ NewBvOutputter::UpdateOutputForSeries(SeriesHandler* handler)
     int n_slices = handler->GetNumberOfSlices();
     int ndigits = itos(n_slices).size();
     for (int i = 1; i <= n_slices; ++i) {
-      string postfix = "_";
+      std::string postfix = "_";
       postfix.append(itos(i, ndigits));
       name.SetPostfix((postfix));
       mOutputList.fileNameList.insert(make_pair(output_file_uid + postfix, name));
@@ -193,22 +222,31 @@ NewBvOutputter::UpdateOutputForSeries(SeriesHandler* handler)
       name.SetExt("v16");
       mOutputList.fileNameList.insert(make_pair(output_file_uid, name));
     }
-
   }
-
 }
 
+
+///
+/**
+ */
 void
-NewBvOutputter::SetOption(const string& name, int value)
+NewBvOutputter::SetOption(const std::string& name, int value)
 {
   OutputterBase::SetOption(name, value);
-  if (name.find("skip") != string::npos) { mSkip = value; }
+  if (name.find("skip") != std::string::npos) {
+    mSkip = value;
+  }
 }
 
+
+///
+/**
+ */
 void
-NewBvOutputter::SetOption(const string& name, bool value)
+NewBvOutputter::SetOption(const std::string& name, bool value)
 {
   OutputterBase::SetOption(name, value);
-  if (name.find("v16") != string::npos) { mSaveV16 = value; }
+  if (name.find("v16") != std::string::npos) {
+    mSaveV16 = value;
+  }
 }
-
