@@ -12,9 +12,11 @@
 #include "NewMetaVolume.h"
 
 using namespace jcs;
-using namespace std;
 
 
+///
+/**
+ */
 NewMetaVolume::NewMetaVolume(const char* filename, const char* he, const char* re) 
   : BasicVolumeFormat(filename, he, re)
 {
@@ -42,23 +44,27 @@ NewMetaVolume::WriteHeader(Basic3DHeader* header_3d)
   mHeaderFile << "NDims = " << header->nDims << std::endl;
   
   mHeaderFile << "DimSize =";
-  for (int i = 0; i < header->nDims; ++i)
+  for (int i = 0; i < header->nDims; ++i) {
     mHeaderFile << " " << header->dimSize[i];
+  }
   mHeaderFile << std::endl;
 
   mHeaderFile << "ElementSpacing =";
-  for (int i = 0; i < header->nDims; ++i)
+  for (int i = 0; i < header->nDims; ++i) {
     mHeaderFile << " " << header->elementSpacing[i];
+  }
   mHeaderFile << std::endl;
 
   mHeaderFile << "Position =";
-  for (int i = 0; i < header->nDims; ++i)
+  for (int i = 0; i < header->nDims; ++i) {
     mHeaderFile << " " << header->origin[i];
+  }
   mHeaderFile << std::endl;
 
   mHeaderFile << "Orientation =";
-  for (unsigned int i = 0; i < header->orientation.size(); ++i)
+  for (unsigned int i = 0; i < header->orientation.size(); ++i) {
     mHeaderFile << " " << header->orientation.at(i);
+  }
   mHeaderFile << std::endl;
 
   mHeaderFile << "CenterOfRotation = 0 0 0" << std::endl;
@@ -68,8 +74,8 @@ NewMetaVolume::WriteHeader(Basic3DHeader* header_3d)
   mHeaderFile << "ElementType = " << MET_ValueTypeName[header->elementType] << std::endl;
   mHeaderFile << "HeaderSize = " << header->headerSize << std::endl;
 
-  vector<string>::const_iterator it = header->extraFields.begin();
-  vector<string>::const_iterator it_end = header->extraFields.end();
+  std::vector<std::string>::const_iterator it = header->extraFields.begin();
+  std::vector<std::string>::const_iterator it_end = header->extraFields.end();
   for (; it != it_end; it++) {
     mHeaderFile << *it << std::endl;
   }
@@ -85,6 +91,6 @@ NewMetaVolume::WriteHeader(Basic3DHeader* header_3d)
   mCloseHeaderFile();
 
   if (verbose && !quiet) {
-    std::cout << "Wrote " << mFileName.GetFullPath().mb_str(wxConvLocal) << std::endl;
+    std::cout << "Wrote " << mFileName.GetFullPath() << std::endl;  //.mb_str(wxConvLocal) << std::endl;
   }
 }
