@@ -2,10 +2,6 @@
 /**
 */
 
-#define _CRT_SECURE_NO_WARNINGS
-
-#pragma warning(disable: 4996)
-
 #include <string>
 #include <vector>
 
@@ -13,15 +9,22 @@
 #include "NewSpmVolume.h"
 #include "NewSpmOutputter.h"
 
-using namespace std;
 using namespace jcs;
 
+
+///
+/**
+*/
 NewSpmOutputter::NewSpmOutputter() : 
 Basic3DOutputter(CreateOptions())
 {
 
 }
 
+
+///
+/**
+*/
 Options
 NewSpmOutputter::CreateOptions()
 {
@@ -31,6 +34,9 @@ NewSpmOutputter::CreateOptions()
 }
 
 
+///
+/**
+*/
 BasicVolumeFormat* 
 NewSpmOutputter::GetOutputVolume(const char* file)
 {
@@ -38,6 +44,9 @@ NewSpmOutputter::GetOutputVolume(const char* file)
 }
 
 
+///
+/**
+*/
 int
 NewSpmOutputter::ConvertSeries(SeriesHandler* handler)
 {
@@ -86,6 +95,10 @@ NewSpmOutputter::ConvertSeries(SeriesHandler* handler)
   return 1;
 }
 
+
+///
+/**
+*/
 template <class T>
 SpmConversion<T>::SpmConversion(Basic3DOutputter* outputter, SeriesHandler* handler)
 : Basic3DConversion<T>(outputter, handler)
@@ -93,26 +106,37 @@ SpmConversion<T>::SpmConversion(Basic3DOutputter* outputter, SeriesHandler* hand
   mHeader = new NewSpmHeader();
 }
 
+
+///
+/**
+*/
 template <class T>
 SpmConversion<T>::~SpmConversion()
 {
   delete mHeader;
 }
 
+
+///
+/**
+*/
 template <class T> void
 SpmConversion<T>::ProcessSlice(std::vector<T>& slice)
 {
   std::reverse(slice.begin(), slice.end());
 }
 
+
+///
+/**
+*/
 template <class T> void
 SpmConversion<T>::GetHeaderForSeries()
 {
-
   mHeader->InitHeader();
-  string s;
+  std::string s;
+
   this->mHandler->Find("SeriesDate", s);
-  
   s.copy(mHeader->hist.exp_date, sizeof(mHeader->hist.exp_date));
   
   this->mHandler->Find("SeriesTime", s);
@@ -133,7 +157,7 @@ SpmConversion<T>::GetHeaderForSeries()
   mHeader->dime.dim[3] = this->mHandler->GetNumberOfSlices();
   // dim[3] recalculated in mConvert
 
-  vector<double>voxel_size = this->mHandler->GetVoxelSize();
+  std::vector<double>voxel_size = this->mHandler->GetVoxelSize();
   mHeader->dime.pixdim[1] = voxel_size[0];
   mHeader->dime.pixdim[2] = voxel_size[1];
   mHeader->dime.pixdim[3] = voxel_size[2];
@@ -180,6 +204,11 @@ SpmConversion<T>::GetHeaderForSeries()
   mHeader->hist.origin[2] = mHeader->dime.dim[3]/2;
 }
 
+
+///
+/**
+    \param volPair A volume identifier and a volume.
+*/
 template <class T> void
 SpmConversion<T>::CompleteHeaderForVolume(std::pair<VolId, Volume<T> > volPair)
 {
@@ -193,7 +222,7 @@ SpmConversion<T>::CompleteHeaderForVolume(std::pair<VolId, Volume<T> > volPair)
   }
 
   double slope, intercept;
-  if (this->mOutputter->rescale == false &&  //0 &&
+  if (this->mOutputter->rescale == false &&
       this->mHandler->GetRescaleSlopeAndIntercept(volPair.first, slope, intercept)) {
     mHeader->dime.scale = slope;
     mHeader->dime.intercept = intercept;
