@@ -48,8 +48,10 @@ mOutputter(outputter)
 void
 NiftiOptionsDlg::OnOkay(wxCommandEvent& event)
 {
-  mNeedsRebuild = Rebuild() || (SaveNii() != mOutputter->saveNii) ||
-  SaveNameFields();
+  bool nfSave = SaveNameFields();
+  bool niiSave = (SaveNii() != mOutputter->saveNii);
+  bool rbld = Rebuild();
+  mNeedsRebuild = nfSave || niiSave || rbld;
   BasicOptionsDlg::OnOkay(event);
   mOutputter->SetSaveNii(SaveNii());
   EndModal(event.GetId());
