@@ -1,15 +1,10 @@
-#include <string>
+/// OutputFactory.cpp
+/**
+ */
 
-#include "NewSpmOutputter.h"
-#include "NewMetaOutputter.h"
-#include "NewBvOutputter.h"
-#include "AnalyzeOutputter.h"
-#include "NiftiOutputter.h"
-#include "FslNiftiOutputter.h"
 #include "OutputFactory.h"
 
 using namespace jcs;
-using std::string;
 
 OutputterBase*
 OutputFactory::CreateNewOutputter(int type)
