@@ -3,14 +3,11 @@
     of files to be produced.
 */
 
-#pragma warning( disable : 4786 )
-
 #if defined(__WXGTK__) || defined(__WXMOTIF__)
-        #include <wx/wx.h>
+  #include <wx/wx.h>
 #endif
 
 #include <wx/wxprec.h>
-
 #include <wx/treectrl.h>
 #include <wx/imaglist.h>
 #include <wx/filename.h>
@@ -27,9 +24,6 @@
 #include "Converter.h"
 
 using namespace jcs;
-using std::map;
-using std::string;
-using std::vector;
 
 enum {
   MENU_RENAME,
@@ -57,9 +51,8 @@ NewOutputTreeCtrl::NewOutputTreeCtrl(McPanel* parent, wxWindowID id, const wxStr
       /*wxTR_EDIT_LABELS |*/ wxTR_HAS_BUTTONS | wxSUNKEN_BORDER), parentPanel(parent)
 {
   CreateImageList();
-  AddRoot(root, folder_icon, -1, new RootItem(root.mb_str(wxConvLocal), *this));
+  AddRoot(root, folder_icon, -1, new RootItem(root, *this));
   SetItemImage(GetRootItem(), open_folder_icon, wxTreeItemIcon_Expanded);
-
 }
 
 
@@ -91,7 +84,6 @@ NewOutputTreeCtrl::SetOutputter(OutputterBase* outputter)
 void
 NewOutputTreeCtrl::CreateImageList(int size)
 {
-
   wxImageList* images = new wxImageList(size, size, true);
 
   images->Add(wxIcon(folder_xpm));
@@ -99,7 +91,6 @@ NewOutputTreeCtrl::CreateImageList(int size)
   images->Add(wxIcon(file_xpm));
 
   AssignImageList(images);
-
 }
 
 
@@ -111,7 +102,9 @@ NewOutputTreeCtrl::RemoveBranch(wxTreeItemId branch)
 {
   if (branch != GetRootItem()) {
 
-    if (dynamic_cast<FileItem*> (GetItemData(branch))) { return; }
+    if (dynamic_cast<FileItem*> (GetItemData(branch))) {
+      return;
+    }
 
     wxTreeItemId parent = GetItemParent(branch);
     Delete(branch);
@@ -141,20 +134,23 @@ void
 NewOutputTreeCtrl::OnMenuOverride(wxCommandEvent& event)
 {
   wxTreeItemId item = GetSelection();
-  if (item.IsOk()) {
-
-    // this is lame...this control is such a mess
-    OutputTreeItemData* data = dynamic_cast<OutputTreeItemData*>(GetItemData(item));
-
-    string seriesUid = data->GetSeriesUid();
-
-    if (!seriesUid.empty()) {
-      parentPanel->OnOverride(seriesUid);
-      parentPanel->mpConverter->UpdateOutput(seriesUid);
-      Reset();
-      RefreshList();
-    }
+  if (!item.IsOk()) {
+    return;
   }
+
+  // this is lame...this control is such a mess
+  OutputTreeItemData* data = dynamic_cast<OutputTreeItemData*>(GetItemData(item));
+
+  std::string seriesUid = data->GetSeriesUid();
+
+  if (seriesUid.empty()) {
+    return;
+  }
+
+  parentPanel->OnOverride(seriesUid);
+  parentPanel->mpConverter->UpdateOutput(seriesUid);
+  Reset();
+  RefreshList();
 }
 
 
@@ -185,9 +181,11 @@ NewOutputTreeCtrl::FindTreeItem(wxTreeItemId parent, const std::string& uid)
 */
 wxString
 NewOutputTreeCtrl::GetStringSelection() const
-{ 
+{
+  wxString retval = "error";
   wxTreeItemId item = GetSelection();
   if (item.IsOk()) {
+    retval = GetItemText(item);
     return GetItemText(item);
   }
   else {
@@ -216,7 +214,7 @@ NewOutputTreeCtrl::OnMenuRename(wxCommandEvent& event)
   if (item.IsOk()) {
     OutputTreeItemData* data = dynamic_cast<OutputTreeItemData*>(GetItemData(item));
     data->OnRename();
-    parentPanel->SetPathInfo(GetStringSelection());
+//    parentPanel->SetPathInfo(GetStringSelection());
   }
 }
 
@@ -293,8 +291,7 @@ FileItem::FillContextMenu(wxMenu& menu)
 {
   OutputTreeItemData::FillContextMenu(menu);
   menu.Append(MENU_OVERRIDE, _("Override default options"));
-  ImageFileName name = mTreeCtrl.mOutputter->GetImageFileName(GetSeriesUid(), 
-    static_cast<const char*> (mTreeCtrl.GetStringSelection().mb_str(wxConvLocal)));
+  ImageFileName name = mTreeCtrl.mOutputter->GetImageFileName(GetSeriesUid(), mTreeCtrl.GetStringSelection().ToStdString());
   if (!name.isRenameable) {
     wxMenuItem* item = menu.FindItem(MENU_RENAME);
     item->Enable(false);
@@ -308,9 +305,10 @@ FileItem::FillContextMenu(wxMenu& menu)
 void
 FileItem::OnRename()
 {
-  ImageFileName name = mTreeCtrl.mOutputter->GetImageFileName(GetSeriesUid(),
-    static_cast<const char*>(mTreeCtrl.GetStringSelection().mb_str(wxConvLocal)));
-  if (!name.isRenameable) { return; }
+  ImageFileName name = mTreeCtrl.mOutputter->GetImageFileName(GetSeriesUid(), mTreeCtrl.GetStringSelection().ToStdString());
+  if (!name.isRenameable) {
+    return;
+  }
   mTreeCtrl.RenameFiles(GetSeriesUid(), name.GetPrefix());
 }
 
@@ -322,7 +320,6 @@ void
 DirItem::OnRename()
 {
   mTreeCtrl.RenameDir(GetId());
-
 }
 
 
@@ -330,14 +327,14 @@ DirItem::OnRename()
 /**
 */
 void
-NewOutputTreeCtrl::RenameFiles(string series_uid, string prefix)
+NewOutputTreeCtrl::RenameFiles(std::string series_uid, std::string prefix)
 {
   wxTextEntryDialog* te_dlg
-    = new wxTextEntryDialog(this, _("Please enter new name"), 
-      _("Rename output files"), wxString(prefix.c_str(), wxConvLocal));
+    = new wxTextEntryDialog(this, _("Please enter new name"), _("Rename output files"), prefix);
+                            //wxString(prefix.c_str(), wxConvLocal));
 
   if (te_dlg->ShowModal() == wxID_OK) {
-    mOutputter->ChangeFileName(series_uid, static_cast<const char*>(te_dlg->GetValue().mb_str(wxConvLocal)));
+    mOutputter->ChangeFileName(series_uid, te_dlg->GetValue().ToStdString());
     Reset();
     RefreshList();
   }
@@ -381,10 +378,9 @@ NewOutputTreeCtrl::RenameDir(wxTreeItemId diritem)
       uids.push_back(data->GetUid());
     }
 
-    mOutputter->ChangeDirName(uids, static_cast<const char*>(te_dlg->GetValue().mb_str(wxConvLocal)), position);
+    mOutputter->ChangeDirName(uids, te_dlg->GetValue().ToStdString(), position);
     Reset();
     RefreshList();
-
   }
 }
 
@@ -430,12 +426,11 @@ NewOutputTreeCtrl::RefreshList()
 {
   OutputList::ListType::iterator it = mOutputter->mOutputList.fileNameList.begin();
   OutputList::ListType::iterator it_end = mOutputter->mOutputList.fileNameList.end();
-
-  while (it != it_end) {
+  for (;it != it_end; ++it) {
     int nDirs = it->second.GetDirCount();
     wxTreeItemId parent = GetRootItem();
     for (int i = 0; i < nDirs; ++i) {
-      string dirUid = it->second.GetDirUid(i);
+      std::string dirUid = it->second.GetDirUid(i);
       wxTreeItemIdValue cookie;
       wxTreeItemId item = GetFirstChild(parent, cookie);
       while (item.IsOk()) {
@@ -448,8 +443,7 @@ NewOutputTreeCtrl::RefreshList()
       }
       if (!item.IsOk()) {
         DirItem* new_item = new DirItem(dirUid, *this);
-        AppendItem(parent, wxString(wxString::From8BitData(it->second.GetDirName(i).c_str()).mb_str(), wxConvLocal), 
-          folder_icon, -1, new_item);
+        AppendItem(parent, wxString(it->second.GetDirName(i)), folder_icon, -1, new_item);
         item = new_item->GetId();
       }
       parent = item;
@@ -458,7 +452,7 @@ NewOutputTreeCtrl::RefreshList()
     // Only add if file isn't already there
     wxTreeItemIdValue cookie;
     wxTreeItemId item = GetFirstChild(parent, cookie);
-    string file_uid = it->first + it->second.GetExt();
+    std::string file_uid = it->first + it->second.GetExt();
     while (item.IsOk()) {
       OutputTreeItemData* data = dynamic_cast<OutputTreeItemData*>(GetItemData(item));
       if (data->GetUid() == file_uid) {
@@ -470,12 +464,12 @@ NewOutputTreeCtrl::RefreshList()
     if (!item.IsOk()) {
       FileItem* new_file_item = new FileItem(file_uid, *this);
       new_file_item->SetSeriesUid(it->second.seriesUid);
-      AppendItem(parent, wxString(wxString::From8BitData(it->second.GetFullName().c_str()).mb_str(), wxConvLocal), 
-        file_icon, -1, new_file_item);
+      AppendItem(parent, wxString(it->second.GetFullName()), file_icon, -1, new_file_item);
     }
-    ++it;
   }
-  if (!mOutputter->mOutputList.fileNameList.empty()) { Expand(GetRootItem()); }
+  if (!mOutputter->mOutputList.fileNameList.empty()) {
+    Expand(GetRootItem());
+  }
 }
 
 
@@ -484,15 +478,17 @@ NewOutputTreeCtrl::RefreshList()
     \param seriesUid String representation of the series.
 */
 void
-NewOutputTreeCtrl::RemoveSeries(const string& seriesUid)
+NewOutputTreeCtrl::RemoveSeries(const std::string& seriesUid)
 {
-  vector<wxTreeItemId> items_to_delete;
+  std::vector<wxTreeItemId> items_to_delete;
   wxTreeItemId root = GetRootItem();
   CheckChildren(root, items_to_delete, seriesUid);
   while (!items_to_delete.empty()) {
-    for(vector<wxTreeItemId>::iterator it = items_to_delete.begin();
-      it != items_to_delete.end(); ++it) 
+    std::vector<wxTreeItemId>::iterator it = items_to_delete.begin();
+    std::vector<wxTreeItemId>::iterator it_end = items_to_delete.end();
+    for (; it != it_end; ++it) {
       Delete(*it);
+    }
     items_to_delete.clear();
     CheckChildren(root, items_to_delete, seriesUid);
   }
@@ -503,7 +499,7 @@ NewOutputTreeCtrl::RemoveSeries(const string& seriesUid)
 /**
 */
 void
-NewOutputTreeCtrl::CheckChildren(wxTreeItemId& parent, vector<wxTreeItemId>& items, const string& seriesUid)
+NewOutputTreeCtrl::CheckChildren(wxTreeItemId& parent, std::vector<wxTreeItemId>& items, const std::string& seriesUid)
 {
   wxTreeItemIdValue cookie;
   wxTreeItemId item = GetFirstChild(parent, cookie);
