@@ -64,7 +64,7 @@ namespace jcs {
     virtual void SetOption(const std::string& name, bool value);
     ///
     /** Sets the boolOption 'split' to 'value'.
-	/param value True means to save series in separate directories.
+        \param value True means to save series in separate directories.
     */
     void SetSplit(bool value) { mOptions.boolOptions["split_dir"] = value; }
     bool GetSplit() { return mOptions.boolOptions["split_dir"]; }
@@ -72,16 +72,28 @@ namespace jcs {
     void SetSplitSubj(bool value) { mOptions.boolOptions["split_subj"] = value; }
     bool GetSplitSubj() { return mOptions.boolOptions["split_subj"]; }
 
+    void SetFlexFormat(bool value) { fnFlexFormat = value; }
+    bool GetFlexFormat() { return fnFlexFormat; }
+
+    void fnAppendComponent(wxString component) { fnComponents.Add(component); }
+
     OutputList mOutputList;
 
+    // For management of output file naming.
     struct NameField
     {
+      /// Name of the field, should follow canonical DICOM standard.
       std::string name;
+      /// Indicates whether instance should be included in the output filename.
       bool value;
+      /// Abbreviation, used by mcverter filename formatting string.
+      wxString abbr;
+      // Constructors
       NameField() {}
-    NameField(std::string n, bool v) : name(n), value(v) {}
+      NameField(std::string n, bool v) : name(n), value(v) {}
+      NameField(std::string n, bool v, wxString a) : name(n), value(v), abbr(a) {}
     };
-
+    
     /// DICOM field names used for naming output files.
     enum {
       PatientName,
@@ -102,8 +114,13 @@ namespace jcs {
     // the above enum to provide keys.
     typedef std::map<int, std::string> NameFields;
     NameFields dfn;
+    NameFields abbr;
 
   protected :
+    // Determines what kind of formatting to use for output filenames,
+    // specifically in GenerateDefaultPrefix.
+    bool fnFlexFormat;
+    wxArrayString fnComponents;
     std::map<VolId, std::string> volKeyMap;
     Options mOptions;
     std::map<std::string, Options> overrides;
@@ -115,7 +132,6 @@ namespace jcs {
     bool FindBoolInOverrides(const std::string& series_uid, const std::string& seek, bool& value);
 
   };
-
 }
 
 #endif
