@@ -9,11 +9,10 @@
 #include <istream>
 
 namespace jcs {
-  // Proof-of-concept for data that knows how it should be read.
   struct Preamble {
     char buff[4];
     std::string magic;
-    bool DICM();
+    bool IsDICOM();
     friend std::istream &operator>>(std::istream &in, Preamble &p);
   };
   std::istream &operator>>(std::istream &in, Preamble &p);
