@@ -80,7 +80,7 @@ SeriesHandler::GetIppForFirstSlice(const VolId& id)
 
 
 ///
-/** Retrieves voxel dimensions based on PixelSpacing, SliceSpacing and
+/** Retrieves voxel dimensions based on PixelSpacing, SpacingBetweenSlices //SliceSpacing and
     SliceThickness.
     \return A three-vector of double representing the voxel dimensions.
 */
@@ -90,10 +90,11 @@ SeriesHandler::GetVoxelSize()
   std::vector<double> voxel_size(3, 0);
   std::string s;
   if (Find("PixelSpacing", s)) {
-    voxel_size[0] = stof(s, 0);
-    voxel_size[1] = stof(s, 1);
+    voxel_size[0] = jcs::stof(s, 0);
+    voxel_size[1] = jcs::stof(s, 1);
   }
-  Find("SliceSpacing", voxel_size[2]);
+  //Find("SliceSpacing", voxel_size[2]);
+  Find("SpacingBetweenSlices", voxel_size[2]);
   if (voxel_size[2] == 0) {
     Find("SliceThickness", voxel_size[2]);
   }
@@ -128,7 +129,7 @@ SeriesHandler::GetFilenames() const
   std::vector<std::string> names;
   FileMapType::const_iterator it = mFileMap.begin();
   FileMapType::const_iterator it_end = mFileMap.end();
-  for (; it != it_end; it++) {
+  for (; it != it_end; ++it) {
     names.push_back(it->first);
   }
   return names;
@@ -141,7 +142,9 @@ SeriesHandler::GetFilenames() const
 bool
 SeriesHandler::IsBigEndian() const
 {
-  if (mFileMap.empty()) { return false; }
+  if (mFileMap.empty()) {
+    return false;
+  }
   DicomFile dicomFile((*mFileMap.begin()).first.c_str());
   return dicomFile.IsBigEndian();
 }
@@ -240,7 +243,7 @@ SeriesHandler::GetVolumeInterval() const
     \return An estimate for volume interval.
 */
 double
-SeriesHandler::CalculateVolIntVal(std::map<VolId, std::vector<double> >& vtmap, int min_num_volumes) const
+SeriesHandler::CalculateVolIntVal(std::map<VolId, std::vector<double> >& vtmap, unsigned int min_num_volumes) const
 {
   double retval = 0;
   if (vtmap.size() > min_num_volumes) {
@@ -343,7 +346,10 @@ int
 SeriesHandler::GetColumns()
 {
   int columns;
-  Find("ImageColumns", columns);
+//  Find(DT_IMAGECOLUMNS, columns);
+	  Find(DT_IMAGECOLUMNS, columns);
+  //Find(DT_IMAGECOLUMNS, columns);
+	  Find("Columns", columns);
   return columns;
 }
 
@@ -356,7 +362,11 @@ int
 SeriesHandler::GetRows()
 {
   int rows;
-  Find("ImageRows", rows);
+
+//  Find(DT_IMAGEROWS, rows);
+  Find (DT_IMAGEROWS, rows);
+  //Find(DT_IMAGEROWS, rows);
+  Find("Rows", rows);
   return rows;
 }
 
@@ -388,7 +398,8 @@ SeriesHandler::AddFile(const char* filename)
   DicomFile dicom_file(filename);
 
   std::string series_uid;
-  dicom_file.Find("SeriesInstanceUid", series_uid);
+  //dicom_file.Find("SeriesInstanceUid", series_uid);
+  dicom_file.Find("SeriesInstanceUID", series_uid);
 
   // Fix problems with termination
   std::string temp(series_uid.c_str());
@@ -398,7 +409,8 @@ SeriesHandler::AddFile(const char* filename)
   assert(mSeriesUid == series_uid);
 
   std::string uid;
-  dicom_file.Find("SopInstance", uid);
+  //dicom_file.Find("SopInstance", uid);
+  dicom_file.Find("SOPInstanceUID", uid);
   if (mInstanceUids.count(uid) == 0 ) {
     mInstanceUids.insert(uid);
     VolListType info = ReadVolIds(dicom_file);
@@ -406,9 +418,11 @@ SeriesHandler::AddFile(const char* filename)
   }
   
   if (seriesInfo.SeriesDate == "") {
-    Find("PatientId", seriesInfo.subject_id);
+    //Find("PatientId", seriesInfo.subject_id);
+    Find("PatientID", seriesInfo.subject_id);
     Find("PatientName", seriesInfo.subject_name);
-    Find("StudyId", seriesInfo.study_number);
+    //Find("StudyId", seriesInfo.study_number);
+    Find("StudyID", seriesInfo.study_number);
     Find("StudyDescription", seriesInfo.study_description);
     int series_number;
     Find("SeriesNumber", series_number);
@@ -423,7 +437,7 @@ SeriesHandler::AddFile(const char* filename)
 
 
 ///
-/** Retreieves a bunch of information about a series.
+/** Retrieves a bunch of information about a series.
     \return A vector of strings with series information.
 */
 std::vector<std::string>
@@ -439,26 +453,35 @@ SeriesHandler::GetStringInfo()
   v.push_back(std::string("Subject: ") + Find("PatientName"));
   v.push_back(std::string("Subject birth date: ") + Find("PatientBirthDate"));
   v.push_back(std::string("Series description: ") + Find("SeriesDescription"));
-  v.push_back(std::string("Manufacturer: ") + Find("Manufacturer"));
-  v.push_back(std::string("Model name: ") + Find("ModelName"));
-  v.push_back(std::string("Study id: ") + Find("StudyId"));
+  v.push_back(std::string("Image type: ") + Find("ImageType"));
+ 
+  std::string manufacturer = Find("Manufacturer");
+  v.push_back(std::string("Manufacturer: ") + manufacturer);
+
+  v.push_back(std::string("Model name: ") + Find("ManufacturerModelName"));
+  v.push_back(std::string("Software version: ") + Find("SoftwareVersions"));
+  v.push_back(std::string("Study id: ") + Find("StudyID"));
   v.push_back(std::string("Series number: ") + Find("SeriesNumber"));
   v.push_back(std::string("Repetition time (ms): ") + Find("RepetitionTime"));
 
   GetEchoTimes();
-  for(unsigned int i = 0; i < echo_times.size(); i++) {
-    v.push_back(std::string("Echo time[" + itos(i) + "] (ms): ") + echo_times[i]);
+  std::map<int, std::string>::iterator echo_it = echo_times.begin();
+  while (echo_it != echo_times.end()) {
+    v.push_back(std::string("Echo time[" + itos(echo_it->first) + "] (ms): ") + echo_it->second);
+	++echo_it;
   }
 
-  v.push_back(std::string("Inversion time (ms): ") + Find("InversionTime"));
+  std::string found_string;
+  found_string = Find("InversionTime");
+  if (found_string.size() > 0 )
+	  v.push_back(std::string("Inversion time (ms): ") + found_string);
   v.push_back(std::string("Flip angle: ") + Find("FlipAngle"));
   v.push_back(std::string("Number of averages: ") + Find("NumberOfAverages"));
   v.push_back(std::string("Slice thickness (mm): ") + Find("SliceThickness"));
-  v.push_back(std::string("Slice spacing (mm): ") + Find("SliceSpacing"));
-  v.push_back(std::string("Image columns: ") + Find("ImageColumns"));
-  v.push_back(std::string("Image rows: ") + Find("ImageRows"));
-  v.push_back(std::string("Number of frames: ") + Find("NumberOfFrames"));
-  v.push_back(std::string("Phase encoding direction: ") + Find("PhaseEncodingDirection"));
+  v.push_back(std::string("Slice spacing (mm): ") + Find("SpacingBetweenSlices"));
+  v.push_back(std::string("Image columns: ") + Find("Columns"));
+  v.push_back(std::string("Image rows: ") + Find("Rows"));
+  v.push_back(std::string("Phase encoding direction: ") + Find("InPlanePhaseEncodingDirection"));
 
   std::vector<double> voxels = GetVoxelSize();
   v.push_back(std::string("Voxel size x (mm): ") + ftos(voxels[0]));
@@ -468,9 +491,12 @@ SeriesHandler::GetStringInfo()
   v.push_back(std::string("Number of volumes: ") + itos(nVolumes));
   v.push_back(std::string("Number of slices: ") + itos(GetNumberOfSlices()));
   v.push_back(std::string("Number of files: ") + itos(GetNumberOfFiles()));
+//  v.push_back(std::string("Number of frames: ") + Find("NumberOfFrames"));
   v.push_back(std::string("Number of frames: ") + itos(GetFrames()));
   v.push_back(std::string("Slice duration (ms) : ") + ftos(GetSliceDuration()));
 
+
+
   if (nVolumes > 1) {
     v.push_back(std::string("Volume interval (s): ") + ftos(GetVolumeInterval()));
   }
@@ -494,7 +520,7 @@ SeriesHandler::GetStringInfo()
 ///
 /** Retrieves echo times for the series. Sets echo_times
     and multiecho.
-    Note that echo_times is indexed by the EchoNumber.
+    Note that echo_times is indexed by the EchoNumbers.
 */
 void
 SeriesHandler::GetEchoTimes()
@@ -507,7 +533,8 @@ SeriesHandler::GetEchoTimes()
   std::set<VolId>::iterator vol_it = volids.begin();
   std::set<VolId>::iterator vol_it_end = volids.end();
   for (; vol_it != vol_it_end; vol_it++) {
-    if (Find("EchoTime", s, *vol_it) && Find("EchoNumber", idx, *vol_it)) {
+    //if (Find("EchoTime", s, *vol_it) && Find("EchoNumber", idx, *vol_it)) {
+    if (Find("EchoTime", s, *vol_it) && Find("EchoNumbers", idx, *vol_it)) {
       echo_times[idx] = s;
     }
   }
@@ -550,23 +577,28 @@ SeriesHandler::ReadVolIds(DicomFile& file)
     ss << frameno;
     info.ids.push_back(ss.str());
     */
-
+    
     std::string str;
     file.Find("NumberOfTemporalPositions", str);
     int ndigits = str.size();
     
     str.clear();
     int tpid = 0;
-    file.Find("TemporalPositionId", tpid);
+    file.Find("TemporalPositionIdentifier", tpid);
     str = itos(tpid, ndigits);
     info.ids.push_back(str);
 
     str.clear();
     int echonumber = 0;
-    file.Find("EchoNumber", echonumber);
+    file.Find("EchoNumbers", echonumber);
     str = itos(echonumber, 2);
     info.ids.push_back(str);
     
+	// added for PET data
+	str.clear();
+	file.Find("FrameReferenceTime", str);
+	info.ids.push_back(str);
+
     std::string ImageType;
     file.Find("ImageType", ImageType);
 
@@ -593,8 +625,8 @@ SeriesHandler::ReadVolIds(DicomFile& file)
         info.ids.push_back("");
       }
     }
-    std::vector<double> rotation(9,0);
-    //rotation.resize(9, 0);
+    std::vector<double> rotation;
+    rotation.resize(9, 0);
 
     std::string iop;
     if (!file.Find("ImageOrientationPatient", iop)) {
@@ -602,7 +634,7 @@ SeriesHandler::ReadVolIds(DicomFile& file)
     }
     
     for (int i = 0; i < 6; ++i) {
-      double f = stof(iop, i);
+      double f = jcs::stof(iop, i);
       // round off
       rotation[i] = static_cast<double>(static_cast<int>(f * 10000 + 0.5)) / 10000;
     }
@@ -621,7 +653,7 @@ SeriesHandler::ReadVolIds(DicomFile& file)
       orientations.push_back(rotation);
     }
     info.ids.push_back(itos(info.orientNumber + 1));
-    
+
     v.push_back(info);
   }
 
@@ -636,13 +668,15 @@ SeriesHandler::ReadVolIds(DicomFile& file)
 std::set<VolId>
 SeriesHandler::GetVolIds() const
 {
+  std::set<VolId> volSet;
+
   FileMapType::const_iterator it = mFileMap.begin();
   FileMapType::const_iterator it_end = mFileMap.end();
-  std::set<VolId> volSet;
-  for(; it != it_end; it++) {
-    VolListType::const_iterator vit = it->second.begin();
-    VolListType::const_iterator vit_end = it->second.end();
-    for (; vit != vit_end; vit++) { 
+  VolListType::const_iterator vit, vit_end;
+  for(; it != it_end; ++it) {
+    vit = it->second.begin();
+    vit_end = it->second.end();
+    for (; vit != vit_end; ++vit) { 
       volSet.insert(*vit);
     }
   }
@@ -659,10 +693,13 @@ SeriesHandler::GetVolIdsAndFiles() const
 {
   std::map<VolId, std::string> volMap;
 
-  FileMapType::const_iterator it;
-  VolListType::const_iterator vit;
-  for (it = mFileMap.begin(); it != mFileMap.end(); it++) {
-    for (vit = it->second.begin(); vit != it->second.end(); vit++) {
+  FileMapType::const_iterator it = mFileMap.begin();
+  FileMapType::const_iterator it_end = mFileMap.end();
+  VolListType::const_iterator vit, vit_end;
+  for (; it != it_end; ++it) {
+    vit = it->second.begin();
+    vit_end = it->second.end();
+    for (; vit != vit_end; ++vit) {
       volMap[*vit] = it->first;
     }
   }
@@ -680,10 +717,13 @@ SeriesHandler::GetVolIdsAndFiles() const
 bool
 SeriesHandler::GetFirstFilename(const VolId& id, std::string& str) const
 {
-  FileMapType::const_iterator it;
-  VolListType::const_iterator vit;
-  for (it = mFileMap.begin(); it != mFileMap.end(); it++) {
-    for (vit = it->second.begin(); vit != it->second.end(); vit++) {
+  FileMapType::const_iterator it = mFileMap.begin();
+  FileMapType::const_iterator it_end = mFileMap.end();
+  VolListType::const_iterator vit, vit_end;
+  for (; it != it_end; ++it) {
+    vit = it->second.begin();
+    vit_end = it->second.end();
+    for (; vit != vit_end; ++vit) {
       if (*vit == id) {
         str = it->first;
         return true;
@@ -721,8 +761,7 @@ SeriesHandler::GetImageComments(std::vector<std::string>& comments) const
   std::map<VolId, std::string> volFileMap = GetVolIdsAndFiles();
   std::map<VolId, std::string>::iterator it = volFileMap.begin();
   std::map<VolId, std::string>::iterator it_end = volFileMap.end();
-
-  for (;it != it_end; it++) {
+  for (;it != it_end; ++it) {
     std::string comment;
     DicomFile file(it->second.c_str());
     file.Find("ImageComments", comment);
