@@ -158,7 +158,7 @@ namespace jcs {
     virtual std::string GetImagePositionPatient(DicomFile& dfile, int frame);
     double GetMeanVolumeInterval(std::vector<double>& vol_times) const;
     void CheckIntervalSanity(std::vector<double>& vol_times, double value) const;
-    double CalculateVolIntVal(std::map<VolId, std::vector<double> >& vtmap, int min_num_volumes) const;
+    double CalculateVolIntVal(std::map<VolId, std::vector<double> >& vtmap, unsigned int min_num_volumes) const;
     private :
     // moved over from DicomSeries
     const std::string mSeriesUid;
