@@ -15,7 +15,7 @@ using namespace jcs;
 void
 DicomValue::GetStrings(std::istream &in)
 {
-  char in_buff[100];
+//  char in_buff[100];
   std::string tmp;
   while (!std::getline(in, tmp, '\\').fail()) {
      //(char)0x5C);
